#ifndef CALC_H
#define CALC_H

double qcalculate (const QString &expression);

#endif // CALC_H
